# PyGT : Python analysis of metastable Markov models using graph transformation

>Tom Swinburne, CNRS-CINaM, 2019, swinburne@cinam.univ-mrs.fr
>Deepti Kannan, U Cambridge

Docs will be available at readthedocs

# INSTALLATION (beta)
```
pip install -i https://test.pypi.org/simple/ PyGT-tomswinburne==0.1.0
```
